DeLU (Deep Learning Utilities)
==============================

.. raw:: html

  <img src="https://raw.githubusercontent.com/Yura52/delu/main/docs/images/logo.png" width="130px" style="text-align:center;display:block;">

.. __INCLUDE_0__

DeLU is a general-purpose PyTorch library that simplifes development and training of deep learning models.
DeLU is a toolbox, not a framework:

- DeLU provides functions and classes that facilitate training loops, reproducibility, tensor manipulations and other typical aspects of deep learning projects.
- there is no need to "rebuild your project around DeLU": you can start using DeLU by picking individual tools that you find helpful.

DeLU is tested and battle-tested in research projects. The public API is still evolving,
and backward-incompatible changes are possible.

Overview
--------

- `Website <https://yura52.github.io/delu>`_
- `Learn DeLU <https://yura52.github.io/delu/stable/learn>`_
- `Classification task example (MNIST) <https://github.com/Yura52/delu/blob/main/examples/mnist.py>`_
- `Code <https://github.com/Yura52/delu>`_

.. __INCLUDE_1__

Installation
------------

.. code-block:: bash

    pip install delu

**Dependencies:** see `pyproject.toml` in the repository.

How to contribute
-----------------

- Help to resolve `issues <https://github.com/Yura52/delu/issues>`_
- Report `bugs and issues <https://github.com/Yura52/delu/issues/new/choose>`_
- Post `questions, ideas and feedback <https://github.com/Yura52/delu/discussions/new>`_

If your contribution includes pull requests, see `CONTRIBUTING.md <https://github.com/Yura52/delu/blob/main/other/CONTRIBUTING.md>`_

How to cite
-----------

.. code-block:: none

    @article{gorishniy2020delu,
        title={DeLU: a Lightweight Toolbox for Deep Learning Researchers and Practitioners},
        author={Yury Gorishniy},
        journal={GitHub},
        volume={Yura52/delu},
        url={https://github.com/Yura52/delu},
        year={2020},
    }
